@@ -31,13 +31,16 @@ setMethod(
         else
             score <- eval(object@data$score, envir = sys.frame(object@data$frame))
         
-        if(inherits(object, "C1.curve") | inherits(object, "C1.dotplot") | inherits(object, "C1.interval"))
+        if(inherits(object, "C1.barchart") | inherits(object, "C1.curve") | inherits(object, "C1.dotplot") | inherits(object, "C1.interval"))
             if(object@data$storeData)
                 at <- object@data$at
             else
                 at <- eval(object@data$at, envir = sys.frame(object@data$frame))
         
-        score <- as.matrix(score)[, 1]  ## to manage 'score' when it is a data.frame with only one column
+        if(inherits(object, "C1.curves"))
+            score <- as.matrix(score)
+        else
+            score <- as.matrix(score)[, 1]  ## to manage 'score' when it is a data.frame with only one column
         
         if(class(object) == "C1.interval")  ## to manage only the first score in c(score1, score2)
             score <- score[1:(length(score) / 2)]
@@ -108,13 +111,6 @@ setMethod(
             if(is.null(object@g.args$xlim))
                 object@g.args$xlim <- lim
             
-            if(inherits(object, "C1.curve") | inherits(object, "C1.dotplot") | inherits(object, "C1.interval"))
-                if(!is.null(at))
-                    scalesandlab$y$at <- at
-            
-            if(is.null(scalesandlab$y$at))
-                scalesandlab$y$at <- 1:NROW(score)
-            
         } else {
             ## draw axes for vertical plot
             if(is.null(scalesandlab$y$at))
@@ -123,12 +119,6 @@ setMethod(
             if(is.null(object@g.args$ylim))
                 object@g.args$ylim <- lim
             
-            if(inherits(object, "C1.curve") | inherits(object, "C1.dotplot") | inherits(object, "C1.interval"))
-                if(!is.null(at))
-                    scalesandlab$x$at <- at
-            
-            if(is.null(scalesandlab$x$at))
-                scalesandlab$x$at <- 1:NROW(score)
         }
         
         object@g.args$scales <- scalesandlab
@@ -243,7 +233,9 @@ setMethod(
         ## grid background and box
         object@trellis.par$panel.background$col <- object@adeg.par$pbackground$col
         if(!object@adeg.par$pbackground$box)
-            object@trellis.par$axis.line$col <- "transparent"
+          object@trellis.par$axis.line$col <- "transparent"
+        else
+          object@trellis.par$axis.line$col <- "black"
         
         arguments <- list(
             par.settings = object@trellis.par,
@@ -282,16 +274,17 @@ setMethod(
         else
             score <- eval(object@data$score, envir = sys.frame(object@data$frame))
         
-        score <- as.matrix(score)[, 1]  ## to manage 'score' when it is a data.frame with only one column
+        if(inherits(object, "C1.curves"))
+            score <- as.matrix(score)
+        else
+            score <- as.matrix(score)[, 1]  ## to manage 'score' when it is a data.frame with only one column
 
         xdata <- rep(1, length(score))
-        if(inherits(object, "C1.barchart")) {
-            xdata <- 1:length(score)
-        } else if(inherits(object, "C1.dotplot") | inherits(object, "C1.curve") | inherits(object, "C1.interval")) {
-            if(object@data$storeData)
-                xdata <- object@data$at
-            else
-                xdata <- eval(object@data$at, envir = sys.frame(object@data$frame))
+        if(inherits(object, "C1.barchart") | inherits(object, "C1.curve") | inherits(object, "C1.dotplot") | inherits(object, "C1.interval")) {
+          if(object@data$storeData)
+            xdata <- object@data$at
+          else
+            xdata <- eval(object@data$at, envir = sys.frame(object@data$frame))
         }
         
         fml <- as.formula(score ~ xdata)
